@@ -128,12 +128,12 @@ sub create_campaign_budget {
     });
 
   # Issue a mutate request to add the campaign budget.
-  my $campaign_budget_response = $api_client->CampaignBudgetService()->mutate({
+  my $campaign_budgets_response = $api_client->CampaignBudgetService()->mutate({
       customerId => $customer_id,
       operations => [$campaign_budget_operation]});
 
   my $campaign_budget_resource_name =
-    $campaign_budget_response->{results}[0]{resourceName};
+    $campaign_budgets_response->{results}[0]{resourceName};
   printf "Created campaign budget with resource name: '%s'.\n",
     $campaign_budget_resource_name;
 
@@ -194,12 +194,12 @@ sub create_campaign {
     });
 
   # Issue a mutate request to add the campaign.
-  my $campaign_response = $api_client->CampaignService()->mutate({
+  my $campaigns_response = $api_client->CampaignService()->mutate({
       customerId => $customer_id,
       operations => [$campaign_operation]});
 
   my $campaign_resource_name =
-    $campaign_response->{results}[0]{resourceName};
+    $campaigns_response->{results}[0]{resourceName};
   printf "Created App campaign with resource name: '%s'.\n",
     $campaign_resource_name;
 
@@ -255,13 +255,13 @@ sub set_campaign_targeting_criteria {
   }
 
   # Issue a mutate request to add the campaign criterion.
-  my $campaign_criterion_response =
+  my $campaign_criteria_response =
     $api_client->CampaignCriterionService()->mutate({
       customerId => $customer_id,
       operations => $campaign_criterion_operations
     });
 
-  my $campaign_criterion_results = $campaign_criterion_response->{results};
+  my $campaign_criterion_results = $campaign_criteria_response->{results};
   printf "Created %d campaign criteria:\n", scalar @$campaign_criterion_results;
 
   foreach my $campaign_criterion_result (@$campaign_criterion_results) {
@@ -290,12 +290,12 @@ sub create_ad_group {
     new({create => $ad_group});
 
   # Issue a mutate request to add the ad group.
-  my $ad_group_response = $api_client->AdGroupService()->mutate({
+  my $ad_groups_response = $api_client->AdGroupService()->mutate({
       customerId => $customer_id,
       operations => [$ad_group_operation]});
 
   my $ad_group_resource_name =
-    $ad_group_response->{results}[0]{resourceName};
+    $ad_groups_response->{results}[0]{resourceName};
   printf "Created ad group with resource name: '%s'.\n",
     $ad_group_resource_name;
 
@@ -333,12 +333,12 @@ sub create_app_ad {
     ->new({create => $ad_group_ad});
 
   # Issue a mutate request to add the ad group ad.
-  my $ad_group_ad_response = $api_client->AdGroupAdService()->mutate({
+  my $ad_group_ads_response = $api_client->AdGroupAdService()->mutate({
       customerId => $customer_id,
       operations => [$ad_group_ad_operation]});
 
   printf "Created ad group ad with resource name: '%s'.\n",
-    $ad_group_ad_response->{results}[0]{resourceName};
+    $ad_group_ads_response->{results}[0]{resourceName};
 }
 
 # Creates an ad text asset.
