@@ -71,12 +71,12 @@ sub update_campaign {
       updateMask => all_set_fields_of($campaign)});
 
   # Update the campaign.
-  my $campaign_response = $api_client->CampaignService()->mutate({
+  my $campaigns_response = $api_client->CampaignService()->mutate({
       customerId => $customer_id,
       operations => [$campaign_operation]});
 
   printf "Updated campaign with resource name: '%s'.\n",
-    $campaign_response->{results}[0]{resourceName};
+    $campaigns_response->{results}[0]{resourceName};
 
   return 1;
 }
