@@ -102,12 +102,12 @@ sub update_flights_feed_item_string_attribute_value {
       updateMask => all_set_fields_of($feed_item)});
 
   # Update the feed item.
-  my $feed_item_response = $api_client->FeedItemService()->mutate({
+  my $feed_items_response = $api_client->FeedItemService()->mutate({
       customerId => $customer_id,
       operations => [$feed_item_operation]});
 
   printf "Updated feed item with resource name: '%s'.\n",
-    $feed_item_response->{results}[0]{resourceName};
+    $feed_items_response->{results}[0]{resourceName};
 
   return 1;
 }
@@ -182,7 +182,7 @@ pod2usage(2)
 # Call the example.
 update_flights_feed_item_string_attribute_value(
   $api_client, $customer_id =~ s/-//gr,
-  $feed_id, $feed_item_id, $flight_placeholder_field_name,
+  $feed_id,    $feed_item_id, $flight_placeholder_field_name,
   $attribute_value
 );
 
