@@ -47,6 +47,7 @@ use constant IMAGE_URL => "https://goo.gl/3b9Wfh";
 # Running the example with -h will print the command line usage.
 my $customer_id = "INSERT_CUSTOMER_ID_HERE";
 
+# [START upload_image_asset]
 sub upload_image_asset {
   my ($api_client, $customer_id) = @_;
 
@@ -72,15 +73,16 @@ sub upload_image_asset {
     });
 
   # Issue a mutate request to add the asset.
-  my $asset_response = $api_client->AssetService()->mutate({
+  my $assets_response = $api_client->AssetService()->mutate({
       customerId => $customer_id,
       operations => [$asset_operation]});
 
   printf "The image asset with resource name '%s' was created.\n",
-    $asset_response->{results}[0]{resourceName};
+    $assets_response->{results}[0]{resourceName};
 
   return 1;
 }
+# [END upload_image_asset]
 
 # Don't run the example if the file is being included.
 if (abs_path($0) ne abs_path(__FILE__)) {
