@@ -56,6 +56,7 @@ use constant URL_STRING => "url__";
 # Running the example with -h will print the command line usage.
 my $customer_id = "INSERT_CUSTOMER_ID_HERE";
 
+# [START add_expression_rule_user_list]
 sub add_expression_rule_user_list {
   my ($api_client, $customer_id) = @_;
 
@@ -124,14 +125,15 @@ sub add_expression_rule_user_list {
     });
 
   # Issue a mutate request to add the user list and print some information.
-  my $user_list_response = $api_client->UserListService()->mutate({
+  my $user_lists_response = $api_client->UserListService()->mutate({
       customerId => $customer_id,
       operations => [$user_list_operation]});
   printf "Created user list with resource name '%s'.\n",
-    $user_list_response->{results}[0]{resourceName};
+    $user_lists_response->{results}[0]{resourceName};
 
   return 1;
 }
+# [END add_expression_rule_user_list]
 
 # Don't run the example if the file is being included.
 if (abs_path($0) ne abs_path(__FILE__)) {
