@@ -51,6 +51,7 @@ my $user_list_id1 = "INSERT_USER_LIST_ID_1_HERE";
 my $user_list_id2 = "INSERT_USER_LIST_ID_2_HERE";
 my $user_list_ids = [];
 
+# [START add_logical_user_list]
 sub add_logical_user_list {
   my ($api_client, $customer_id, $user_list_ids) = @_;
 
@@ -92,14 +93,15 @@ sub add_logical_user_list {
     });
 
   # Issue a mutate request to add the user list and print some information.
-  my $user_list_response = $api_client->UserListService()->mutate({
+  my $user_lists_response = $api_client->UserListService()->mutate({
       customerId => $customer_id,
       operations => [$user_list_operation]});
   printf "Created combination user list with resource name '%s'.\n",
-    $user_list_response->{results}[0]{resourceName};
+    $user_lists_response->{results}[0]{resourceName};
 
   return 1;
 }
+# [END add_logical_user_list]
 
 # Don't run the example if the file is being included.
 if (abs_path($0) ne abs_path(__FILE__)) {
